#! /usr/bin/env python3
import argparse
import pathlib
import re
import sys

import yaml

from signal import signal, SIGPIPE, SIG_DFL

signal(SIGPIPE, SIG_DFL)


def grep(pattern, file):
    with file.open() as f:
        try:
            data = yaml.safe_load(f)
            try:
                hits = {k: v for k, v in data.items() if re.search(pattern, k)}
                if hits:
                    print('==>', file, '<==')
                    yaml.dump(hits, sys.stdout, default_flow_style=False)
                    print()
            except AttributeError:
                pass
        except yaml.scanner.ScannerError:
            print('Parse error:', file, file=sys.stderr)



def main():
    parser = argparse.ArgumentParser(description='searches and prints YAML (top-level) properties and their values')
    parser.add_argument(
        'pattern',
        action='store',
        help='regex to filter YAML properties on',
    )
    parser.add_argument(
        'files',
        nargs='*',
        help='Files to search, defaults to .yaml under the current directory (recursively).',
        default=[pathlib.Path('.')],
        type=pathlib.Path,
    )
    args = parser.parse_args()

    try:
        pattern = re.compile(args.pattern)
        for root in args.files or ['.']:
            if root.is_dir():
                for file in pathlib.Path(root).rglob('*.yaml'):
                    grep(pattern, file)
            elif root.is_file():
                grep(pattern, root)
            else:
                print('Not a file:', root, file=sys.stderr)
    except KeyboardInterrupt:
        pass


if __name__ == '__main__':
    main()



from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / 'README.md').read_text(encoding='utf-8')

setup(
    name='folkol.yg',
    version='0.0.15',
    description='a unix filter for "greping" in YAML files',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/folkol/yg',
    author='folkol',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Terminals',
        'Topic :: Text Processing :: Filters',
        'License :: OSI Approved :: MIT License',
    ],
    keywords='shell, unix filter',
    packages=["folkol"],
    install_requires=['pyyaml'],
    python_requires='>=3.6, <4',
    entry_points={
        'console_scripts': [
            'yg=folkol.yg:main',
        ],
    },
    project_urls={
        'Bug Reports': 'https://github.com/folkol/yg/issues',
        'Source': 'https://github.com/folkol/yg',
    },
)
